@@ -27,10 +27,11 @@
 #include "vinagre-utils.h"
 #include "vinagre-dnd.h"
 #include "vinagre-bookmarks.h"
+#include "vinagre-bookmarks-ui.h"
 #include "vinagre-window-private.h"
 #include "vinagre-bookmarks-entry.h"
-#include "vinagre-plugin.h"
 #include "vinagre-plugins-engine.h"
+#include "vinagre-commands.h"
 
 #ifdef VINAGRE_ENABLE_AVAHI
 #include "vinagre-mdns.h"
@@ -585,7 +586,6 @@ vinagre_fav_create_toolbar (VinagreFav *fav)
 {
   GtkWidget *toolbar;
   GtkActionGroup *action_group;
-  GtkAction *action;
   GtkUIManager *manager;
   GError *error = NULL;
 
@@ -842,7 +842,7 @@ vinagre_fav_hide (GtkButton *button, VinagreFav *fav)
 static void
 vinagre_fav_create_title (VinagreFav *fav)
 {
-  GtkWidget *box, *label, *close_button, *image, *frame;
+  GtkWidget *box, *label, *close_button, *image;
 
   box = gtk_hbox_new (FALSE, 0);
 
@@ -870,9 +870,18 @@ vinagre_fav_create_title (VinagreFav *fav)
   gtk_widget_show_all (box);
 }
 
+static void
+protocol_added_removed_cb (VinagrePluginsEngine *engine,
+			   VinagreProtocol      *protocol,
+			   VinagreFav           *fav)
+{
+  vinagre_fav_update_list (fav);
+}
+
 static void
 vinagre_fav_constructed (GObject *object)
 {
+  VinagrePluginsEngine *engine;
   VinagreFav *fav = VINAGRE_FAV (object);
 
   if (G_OBJECT_CLASS (vinagre_fav_parent_class)->constructed)
@@ -907,6 +916,16 @@ vinagre_fav_constructed (GObject *object)
                             G_CALLBACK (vinagre_fav_update_list),
                             fav);
 #endif
+
+  engine = vinagre_plugins_engine_get_default ();
+  g_signal_connect_after (engine,
+			  "protocol-added",
+			  G_CALLBACK (protocol_added_removed_cb),
+			  fav);
+  g_signal_connect_after (engine,
+			  "protocol-removed",
+			  G_CALLBACK (protocol_added_removed_cb),
+			  fav);
 }
 
 static void
@@ -962,7 +981,7 @@ vinagre_fav_fill_bookmarks (GtkTreeStore *store, GSList *list, GtkTreeIter *pare
   GSList                *l;
   GtkTreeIter            iter;
   VinagreConnection     *conn;
-  VinagrePlugin         *plugin;
+  VinagreProtocol       *ext;
 
  for (l = list; l; l = l->next)
     {
@@ -994,11 +1013,13 @@ vinagre_fav_fill_bookmarks (GtkTreeStore *store, GSList *list, GtkTreeIter *pare
 
 	  case VINAGRE_BOOKMARKS_ENTRY_NODE_CONN:
 	    conn = vinagre_bookmarks_entry_get_conn (entry);
-	    name = vinagre_connection_get_best_name (conn);
-	    plugin = vinagre_plugins_engine_get_plugin_by_protocol (vinagre_plugins_engine_get_default (),
-								    vinagre_connection_get_protocol (conn));
+	    ext = vinagre_plugins_engine_get_plugin_by_protocol (vinagre_plugins_engine_get_default (),
+								 vinagre_connection_get_protocol (conn));
+	    if (!ext)
+	      continue;
 
-	    pixbuf = vinagre_plugin_get_icon (plugin, 16);
+	    pixbuf = vinagre_protocol_get_icon (ext, 16);
+	    name = vinagre_connection_get_best_name (conn);
 
 	    gtk_tree_store_append (store, &iter, parent_iter);
 	    gtk_tree_store_set (store, &iter,
@@ -1023,10 +1044,9 @@ vinagre_fav_fill_bookmarks (GtkTreeStore *store, GSList *list, GtkTreeIter *pare
 gboolean
 vinagre_fav_update_list (VinagreFav *fav)
 {
-  GtkTreeIter        iter, parent_iter;
-  GtkTreeStore      *store;
-  GSList            *list, *l, *next;
-  GdkPixbuf         *pixbuf;
+  GtkTreeIter   parent_iter;
+  GtkTreeStore *store;
+  GSList       *list;
     
   g_return_val_if_fail (VINAGRE_IS_FAV (fav), FALSE);
 
